### 0.12.4 {small}`2025-05-07`

```{rubric} Features
```
* `theta` in `pp.harmony_integrate` can now be a list or array {pr}`353` {smaller}`S Dicks`

```{rubric} Performance
```
* replace `adata._sanitize` for `pp.highly_variable_genes`. Now only `batch_key` column will be categorized {pr}`355` {smaller}`S Dicks`
* replace `adata._sanitize` for `tl.embedding_density`. Now only `groupby` column will be categorized {pr}`355` {smaller}`S Dicks`
* Refactored `pp.harmony_integrate` to be more memory efficient and faster. {pr}`353` {smaller}`S Dicks`

```{rubric} Bug fixes
```
* Fixes `get.X_to_CPU` for `dask.array` {pr}`360` {smaller}`S Dicks`

```{rubric} Misc
```
* Update notebooks for `anndata>0.11.4` {pr}`356` {smaller}`S Dicks`
